#
# spec file for package python-llvmlite
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without  tests
ExcludeArch:    armv7l
Name:           python-llvmlite
Version:        0.22.0
Release:        lp150.1.1
Summary:        Lightweight wrapper around basic LLVM functionality
License:        BSD-2-Clause
Group:          Development/Languages/Python
Url:            http://llvmlite.pydata.org
Source:         https://files.pythonhosted.org/packages/source/l/llvmlite/llvmlite-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  clang5-devel
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  glibc-devel
BuildRequires:  llvm5-LTO-devel
BuildRequires:  llvm5-devel
BuildRequires:  llvm5-gold
BuildRequires:  ncurses-devel
BuildRequires:  python-enum34
BuildRequires:  python-rpm-macros
BuildRequires:  zlib-devel
%ifpython2
Requires:       python-enum34
%endif
%python_subpackages

%description
A lightweight LLVM python binding for writing JIT compilers

The old llvmpy  binding exposes a lot of LLVM APIs but the mapping of
C++-style memory management to Python is error prone. Numba_ and many JIT
compilers do not need a full LLVM API.  Only the IR builder, optimizer,
and JIT compiler APIs are necessary.

llvmlite is a project originally tailored for Numba's needs, using the
following approach:

* A small C wrapper around the parts of the LLVM C++ API we need that are
  not already exposed by the LLVM C API.
* A ctypes Python wrapper around the C API.
* A pure Python implementation of the subset of the LLVM IR builder that we
  need for Numba.


%prep
%setup -q -n llvmlite-%{version}

%build
export CXX=clang++
%python_build

%install
%python_expand $python setup.py install --prefix=%{_prefix} --root=%{buildroot} --install-lib=%{$python_sitearch}
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%if %{with tests}
%check
cp runtests.py examples/
pushd examples
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitearch}
$python runtests.py
}
popd
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc README.rst LICENSE
%{python_sitearch}/llvmlite/
%{python_sitearch}/llvmlite-%{version}-*.egg-info

%changelog
* Fri Mar 23 2018 toddrme2178@gmail.com
- Update to version 0.22.0
  * In this release, we have changed the locking strategy that
    protects LLVM from race conditions.  Before, the llvmlite user
    (like Numba) was responsible for this locking.  Now, llvmlite
    imposes a global thread lock on all calls into the LLVM API.
    This should be significantly less error prone.  Future llvmlite
    releases may manually exempt some functions from locking once
    they are determined to be thread-safe.
* Thu Jan 11 2018 toddrme2178@gmail.com
- Update to version 0.21.0
  * In this release, we upgrade to LLVM 5.
  * Our build scripts now use conda-build 3.
  * For our prebuilt binaries, GCC 7 toolchain is used on
    unix-like systems
  * The OSX minimum deployment target is 10.9.
* Mon Nov  6 2017 toddrme2178@gmail.com
- Update to 0.20.0
  * Beginning with this minor release, we support wheels for Linux, OSX and Windows.
    Pull requests related to enabling wheels are #294, #295, #296 and #297.
  * There are also fixes to the documentation (#283 and #289).
- Update to 0.19.0
  * PR #281, Issue #280: Fix GEP addrspace issue
  * PR #279: Fix #274 addrspace in gep
  * PR #278: add Readthedocs badge
  * PR #275: Add variables to pass through when doing conda-build
  * PR #273: Fix the behavior of module.get_global
  * PR #272: cmpop contains comparison type, not lhs
  * PR #268, Fix #267: Support packed struct
  * PR #277: Add pass through gcc flags for llvmdev
  * PR #276: Remove jenkins build scripts
- Update to 0.18.0
  * This is a minor release that fixes several issues (#263, #262, #258, #237) with
    the wheel build.  In addition, we have minor fixes for running on PPC64LE
    platforms (#261). And, we added CI testing against PyPy (#253).
* Wed Apr 19 2017 toddrme2178@gmail.com
- Remove unneeded disable_unittest_library_detection.patch
* Tue Apr 18 2017 toddrme2178@gmail.com
- Update to 0.17.1
  * Support LLVM 4
- Implement single-spec version.
* Tue Jan 10 2017 arun@gmx.de
- specfile:
  * update copyright year
  * update line numbers and reg-exp in patch
- update to version 0.15.0:
  * Enhancements:
    + PR #213: Add partial LLVM bindings for ObjectFile.
    + PR #215: Add inline assembly helpers in the builder.
    + PR #216: Allow specifying alignment in alloca instructions.
    + PR #219: Remove unnecessary verify in module linkage.
  * Fixes:
    + PR #209, Issue #208: Fix overly restrictive test for library
    filenames.
* Sat Nov  5 2016 arun@gmx.de
- specfile:
  * removed hardcoded version in %%files section
- update to version 0.14.0:
  * PR #104: Add binding to get and view function control-flow graph.
  * PR #210: Improve llvmdev recipe.
  * PR #212: Add initializer for the native assembly parser.
* Wed Oct 12 2016 toddrme2178@gmail.com
- Use new versioned llvm package names.
* Wed Aug 24 2016 toddrme2178@gmail.com
- Initial version
